@@ -6,8 +6,8 @@ from sqlalchemy.orm import relationship
 
 # AvailabilityRequest class is used, so we must define it here or else it has to be definied by clients of the used class,
 # and they don't necessarily know that they need to do this
-from .availability_request import AvailabilityRequest
-from .availability_series import AvailabilitySeries
+# from .availability_request import AvailabilityRequest
+# from .availability_series import AvailabilitySeries
 
 
 # Note from the future,
