@@ -10,10 +10,12 @@ class AvailabilityRequest(Base):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     fromUser = Column(String(255), ForeignKey('users.cognitoId'), nullable=False)
-    forAvailability = Column(Integer, ForeignKey('availabiltiy.id'), nullable=False)
+    forAvailability = Column(Integer, ForeignKey('availability.id'), nullable=False)
     status = Column(String(31), nullable=False)
 
-    def __init__(self, subjects, from_user, for_availability):
-        self.fromUser = from_user
-        self.forAvailability = for_availability
+    def __init__(self, fromUser, forAvailability):
+        self.fromUser = fromUser
+        self.forAvailability = forAvailability
         self.status = "REQUESTED" # possibilities are REQUESTED, ACCEPTED, DENIED, CANCELED
+        # is it best to have the logic layer handler the default status
+        # TODO enum for possibilities
